@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 #include <unistd.h>
@@ -32,6 +32,8 @@ int main(int argc, char *argv[], char *envp[])
 {
 	int ret = 1;
 
+	compiletime_assert(TD_NR <= TD_ENG_FLAG_SHIFT, "TD_ENG_FLAG_SHIFT");
+
 	if (initialize_fio(envp))
 		return 1;
 
@@ -39,9 +41,12 @@ int main(int argc, char *argv[], char *envp[])
 #error "No available clock source!"
 #endif
 
-	if (parse_options(argc, argv))
+	if (fio_server_create_sk_key())
 		goto done;
 
+	if (parse_options(argc, argv))
+		goto done_key;
+
 	/*
 	 * line buffer stdout to avoid output lines from multiple
 	 * threads getting mixed
@@ -54,11 +59,13 @@ int main(int argc, char *argv[], char *envp[])
 		set_genesis_time();
 
 		if (fio_start_all_clients())
-			goto done;
+			goto done_key;
 		ret = fio_handle_clients(&fio_client_ops);
 	} else
 		ret = fio_backend(NULL);
 
+done_key:
+	fio_server_destroy_sk_key();
 done:
 	deinitialize_fio();
 	return ret;
