@@ -37,10 +37,10 @@ int main(int argc, char *argv[])
 
 	nvalues = strtoul(argv[3], NULL, 10);
 
-	init_rand(&s, true);
+	init_rand(&s, false);
 
 	for (i = 0; i < nvalues; i++) {
-		int v = rand_between(&s, start, end);
+		int v = rand32_between(&s, start, end);
 
 		buckets[v - start]++;
 	}
@@ -54,15 +54,15 @@ int main(int argc, char *argv[])
 	pass = fail = 0;
 	for (i = 0; i < index; i++) {
 		if (buckets[i] < vmin || buckets[i] > vmax) {
-			printf("FAIL bucket%4lu: val=%8lu (%.1f < %.1f > %.1f)\n", i + 1, buckets[i], vmin, mean, vmax);
+			printf("FAIL bucket%4lu: val=%8lu (%.1f < %.1f > %.1f)\n", (unsigned long) i + 1, buckets[i], vmin, mean, vmax);
 			fail++;
 		} else {
-			printf("PASS bucket%4lu: val=%8lu (%.1f < %.1f > %.1f)\n", i + 1, buckets[i], vmin, mean, vmax);
+			printf("PASS bucket%4lu: val=%8lu (%.1f < %.1f > %.1f)\n", (unsigned long) i + 1, buckets[i], vmin, mean, vmax);
 			pass++;
 		}
 	}
 
 	printf("Passes=%lu, Fail=%lu\n", pass, fail);
-
+	free(buckets);
 	return 0;
 }
